#MSUB -r moistcr1
#MSUB -o moistc.out_%I
#MSUB -e moistc.out_%I
#MSUB -n 1
#MSUB -T 36000
#MSUB -q xlarge
#MSUB -c 8
#MSUB -Q normal
#MSUB -A gen0239
#MSUB -m store,work,scratch
##MSUB -A ls3cmip6 
set +vx

# Script to create nudging file for soil moisture. 
# This creates a climatology of the soil moisture over 1980-2014 with daily frequency.
#
# 1. Daily output for the years 1980-2014 from the simulation CM61-LR-hist-03.1910 are used.
# 2. The variable moistc is first splitted into moistc_1, moistc_2, moistc_3 to remove the axes on soiltiles.
# 3. For years with 366 days, the 31 of decembre is removed to enable making the median over all years.
# 4. The median is calculated over the whole period 1980-2014 to obtain one year climatologie file with daily frequency.
# 5. The last day is duplicated to have 366 days in the file. 
#
# $HeadURL$
# $Date$
# $Revision$
#######################################################################################################################
date
JobName=CM61-LR-hist-03.1910
mkdir run_moistc_${JobName}
cd run_moistc_${JobName}

echo Start
# 1. historical r1: CM61-LR-hist-03.1910
simulpath=/ccc/store/cont003/gencmip6/p86caub/IGCM_OUT/IPSLCM6/PROD/historical/CM61-LR-hist-03.1910/SRF/Output/DA
allpack=" 19800101_19891231 19900101_19991231 20000101_20091231 20100101_20141231 "

# 2. Extract moistc
echo Extract variable moistc from pack files
# float moistc(time_counter, soiltyp, solay, lat, lon)

for pack in ${allpack} ; do
  echo Treat file ${simulpath}/${JobName}_${pack}_DA_sechiba_out_2.nc
  ncks -v moistc ${simulpath}/${JobName}_${pack}_DA_sechiba_out_2.nc moistc_${pack}_DA_sechiba_out_2.nc
done

echo Separate into variables per soiltile
for pack in ${allpack} ; do
  ncks -d soiltyp,0,0 moistc_${pack}_DA_sechiba_out_2.nc moistc1_${pack}_DA_sechiba_out_2.nc
  ncks -d soiltyp,1,1 moistc_${pack}_DA_sechiba_out_2.nc moistc2_${pack}_DA_sechiba_out_2.nc
  ncks -d soiltyp,2,2 moistc_${pack}_DA_sechiba_out_2.nc moistc3_${pack}_DA_sechiba_out_2.nc

  ncrename -v moistc,moistc_1 moistc1_${pack}_DA_sechiba_out_2.nc
  ncrename -v moistc,moistc_2 moistc2_${pack}_DA_sechiba_out_2.nc
  ncrename -v moistc,moistc_3 moistc3_${pack}_DA_sechiba_out_2.nc
done

echo Remove dimension soiltyp (which is now 1) by averaging over the dimension. Put all variables in the same file.
for pack in ${allpack} ; do
  for soiltyp in 1 2 3 ; do
    ncwa -A -a soiltyp  moistc${soiltyp}_${pack}_DA_sechiba_out_2.nc moistc_allsoil_${pack}_DA_sechiba_out_2.nc 
  done
  ncatted -a long_name,moistc_1,m,c,"Soil Moisture profile for soil tile 1" moistc_allsoil_${pack}_DA_sechiba_out_2.nc 
  ncatted -a long_name,moistc_2,m,c,"Soil Moisture profile for soil tile 2" moistc_allsoil_${pack}_DA_sechiba_out_2.nc 
  ncatted -a long_name,moistc_3,m,c,"Soil Moisture profile for soil tile 3" moistc_allsoil_${pack}_DA_sechiba_out_2.nc 
done

echo Separate per year
for pack in ${allpack} ; do
  cdo splityear moistc_allsoil_${pack}_DA_sechiba_out_2.nc moistc_
done

# 3. Remove one time step in leap years
echo Remove last time step 31 of december from leap years
allleap=" 1980 1984 1988 1992 1996 2000 2004 2008 2012 "
for year in $allleap ; do
  mv moistc_${year}.nc moistc_${year}.leap.nc 
  ncks -d time_counter,0,364 moistc_${year}.leap.nc moistc_${year}.365.nc 
  cp moistc_${year}.365.nc moistc_${year}.nc 
done

# 4. Calculate the median
echo Calculate median
cdo enspctl,50 moistc_????.nc moistc_clim_1980_2014.nc

# 5. Duplicate last day to make a file with 366days
echo Duplicate last day to make a file with 366days
# Extract last day
cdo seltimestep,365 moistc_clim_1980_2014.nc moistc_clim_365.nc
# Switch time axis one day ahead
ncatted -O -a units,time_counter,m,c,"seconds since 1850-01-02 00:00:00"  moistc_clim_365.nc 
# Merge with clim file
ncrcat moistc_clim_1980_2014.nc moistc_clim_365.nc moistc_clim_1980_2014_366d.nc 

echo End

